@@ -340,7 +340,7 @@ setMethod(".addhandlerkeystroke",
                              user.data.first = TRUE,
                              data = list(obj=obj,handler=handler, action=action)
                              )
-            return(ID)
+            invisible(ID)
           })
 
 
